;; Generated package description from project.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "project" "0.12.0.0.20260716.0" "Operations on the current project" '((emacs "26.1") (xref "1.7.0")) :commit "3c0bc3f2ebe54007905f5f81f0418de7fefe8076" :url "https://elpa.gnu.org/packages/project.html")
